@@ -15,11 +15,11 @@ Net::Dropbox::API - A dropbox API interface
 
 =head1 VERSION
 
-Version 0.9.8
+Version 1.0.0.10.10.9.8
 
 =cut
 
-our $VERSION = '0.9';
+our $VERSION = '1.0';
 
 
 =head1 SYNOPSIS
@@ -46,7 +46,6 @@ has 'debug' => (is => 'rw', isa => 'Bool', default => 0);
 has 'error' => (is => 'rw', isa => 'Str', predicate => 'has_error');
 has 'key' => (is => 'rw', isa => 'Str');
 has 'secret' => (is => 'rw', isa => 'Str');
-has 'nonce' => (is => 'ro', isa => 'Str', default => join( '', rand_chars( size => 16, set => 'alphanumeric' ) ));
 has 'login_link' => (is => 'rw', isa => 'Str');
 has 'callback_url' => (is => 'rw', isa => 'Str', default => 'http://localhost:3000/callback');
 has 'request_token' => (is => 'rw', isa => 'Str');
@@ -55,6 +54,7 @@ has 'access_token' => (is => 'rw', isa => 'Str');
 has 'access_secret' => (is => 'rw', isa => 'Str');
 has 'context' => (is => 'rw', isa => 'Str', default => 'sandbox');
 
+
 =head2 login
 
 This sets up the initial OAuth handshake and returns the login URL. This
@@ -287,6 +287,14 @@ normally not need to access this directly.
 
 =cut
 
+=head2 nonce
+
+Generate a different nonce for every request.
+
+=cut
+
+sub nonce { join( '', rand_chars( size => 16, set => 'alphanumeric' )); }
+
 sub _talk {
     my $self    = shift;
     my $command = shift;
@@ -309,8 +317,9 @@ sub _talk {
         token_secret => $self->access_secret,
     );
     if($filename) {
-        $opts{extra_params}{file} = $filename;
-        $opts{request_url} = 'http://api-content.dropbox.com/0/'.$command;
+        push @{$content->{file}},$filename;
+        $opts{request_url} = "http://api-content.dropbox.com/0/$command/?".
+            "file=$filename";
     }
 
     my $request = Net::OAuth->request("protected resource")->new( %opts );
@@ -343,6 +352,10 @@ sub _talk {
 
 Lenz Gschwendtner, C<< <norbu09 at cpan.org> >>
 
+With Bug fixes from:
+Greg Knauss C<< gknauss at eod.com >>
+Chris Prather C<< chris at prather.org >>
+
 =head1 BUGS
 
 Please report any bugs or feature requests to C<bug-net-dropbox-api at rt.cpan.org>, or through
